package com.pfizer.dcbls.sample.bl;

import com.pfizer.dcbls.svc.BusinessLogicDirectory;
import com.pfizer.dcbls.svc.BusinessLogicManager;
import com.pfizer.dcbls.fw.bl.BusinessLogicController;
import com.pfizer.dcbls.fw.bl.RemoteBusinessLogicController;
import com.pfizer.dcbls.fw.FwPersisted;
import com.pfizer.dcbls.fw.FwException;

/**
 * The BusinessLogicDirectory provides the implementation to attach business logic
 * to a component and action.  It also orders the business logic when multiple BL
 * implementations will operate on the component for the same action.  If some
 * business logic is distributed elsewhere in the system, the BusinessLogicDirectory
 * will also set this up.
 * User: ClarkK03
 * Date: Feb 5, 2006
 * Time: 11:42:41 PM
 */
public class SampleBusinessLogicDirectory
    implements BusinessLogicDirectory
{
    public BusinessLogicController getBusinessLogicManager(FwPersisted fwPersisted, String string) throws FwException
    {
        BusinessLogicManager blm = new BusinessLogicManager();
        blm.addBusinessLogic(new SampleAddBusinessLogic(), 50, "add");
        blm.addBusinessLogic(new SampleBusinessLogicController(), 40, null);

        // This creates a business logic entry to run in another Component Manager instance -- thereby making this
        // particular business logic "distributed".  The parameters to the RemoteBusinessLogicController are first
        // the JNDI name of the remote ComponentManager instance, and then the class name of the Business Logic to
        // execute
        blm.addBusinessLogic(new RemoteBusinessLogicController("com.pfizer.dcbls.SampleEJBComponentManager2",
                                                               "com.pfizer.dcbls.sample.bl.SamplePowerBusinessLogic"),
                             50, "power");
        return blm;                        
    }
}
